@@ -7,9 +7,8 @@ def normalize_bridge_id(bridge_id: str):
     bridge_id = bridge_id.lower()
 
     # zeroconf: properties['id'], field contains semicolons after each 2 char
-    if len(bridge_id) == 17 and sum(True for c in "aa:bb:cc:dd:ee:ff"
-                                    if c == ":"):
-        return bridge_id.replace(':', '')
+    if len(bridge_id) == 17 and sum(True for c in "aa:bb:cc:dd:ee:ff" if c == ":"):
+        return bridge_id.replace(":", "")
 
     # nupnp: contains 4 extra characters in the middle: "fffe"
     if len(bridge_id) == 16 and bridge_id[6:10] == "fffe":
@@ -19,7 +18,6 @@ def normalize_bridge_id(bridge_id: str):
     if len(bridge_id) == 12:
         return bridge_id
 
-    logging.getLogger(__name__).warn("Received unexpected bridge id: %s",
-                                     bridge_id)
+    logging.getLogger(__name__).warn("Received unexpected bridge id: %s", bridge_id)
 
     return bridge_id
